From 4b24334fe226bbef8ee0a7818a2f1b581a67f4b7 Mon Sep 17 00:00:00 2001
From: Alyssa Rosenzweig <alyssa.rosenzweig@collabora.com>
Date: Sat, 8 Jan 2022 19:21:20 -0500
Subject: [PATCH 1/3] clk: mediatek: Disable ACP so the GPU works

Workaround from the downstream Mali drivers shipped in ChromeOS. The
code there is unsuitable for mainline but good as a reference for the
hardware behaviour:

https://chromium-review.googlesource.com/c/chromiumos/third_party/kernel/+/2781271/5

I don't see a good reason to add this platform-specific hack to the 3D
driver and need mt8192-specific DT extensions for Panfrost ... as
opposed to setting the appropriate bit in the clock driver already owning this
register so the GPU works as-is.

Signed-off-by: Alyssa Rosenzweig <alyssa.rosenzweig@collabora.com>
---
 drivers/clk/mediatek/clk-mt8192.c | 13 +++++++++++++
 1 file changed, 13 insertions(+)

diff --git a/drivers/clk/mediatek/clk-mt8192.c b/drivers/clk/mediatek/clk-mt8192.c
index cbc7c6dbe0f4..678864a47083 100644
--- a/drivers/clk/mediatek/clk-mt8192.c
+++ b/drivers/clk/mediatek/clk-mt8192.c
@@ -1228,6 +1228,7 @@ static int clk_mt8192_infra_probe(struct platform_device *pdev)
 {
 	struct clk_onecell_data *clk_data;
 	struct device_node *node = pdev->dev.of_node;
+	void __iomem *base;
 	int r;
 
 	clk_data = mtk_alloc_clk_data(CLK_INFRA_NR_CLK);
@@ -1238,6 +1239,18 @@ static int clk_mt8192_infra_probe(struct platform_device *pdev)
 	if (r)
 		return r;
 
+	/* Mali: Disable ACP
+	 * https://chromium-review.googlesource.com/c/chromiumos/third_party/kernel/+/2781271/5
+	 * Otherwise jobs fault senselessly, even trivial null jobs.
+	 */
+	base = devm_platform_ioremap_resource(pdev, 0);
+	if (IS_ERR(base))
+		return PTR_ERR(base);
+
+#define INFRA_CTL 0x290
+#define DIS_MFG2ACP BIT(9)
+	writel(readl(base + INFRA_CTL) | DIS_MFG2ACP, base + INFRA_CTL);
+
 	return of_clk_add_provider(node, of_clk_src_onecell_get, clk_data);
 }
 
-- 
2.34.1

